# -*- coding: utf-8 -*-

from aws_encryption_sdk import CommitmentPolicy
from aws_encryption_sdk import EncryptionSDKClient
from aws_encryption_sdk import StrictAwsKmsMasterKeyProvider
from botocore.session import Session

from core_ciphers.base import Cipher


class KMSCipher(Cipher):
    """ It uses the AWS Encryption SDK for Python """

    def __init__(self, key_arn: str, botocore_session: Session = None, **kwargs):
        super().__init__(**kwargs)
        self.session = botocore_session
        self.key_arn = key_arn

        self.client = EncryptionSDKClient(
            commitment_policy=CommitmentPolicy.REQUIRE_ENCRYPT_REQUIRE_DECRYPT
        )

        kms_kwargs = {"key_ids": [self.key_arn]}
        if self.session:
            kms_kwargs["botocore_session"] = self.session

        self.master_key_provider = StrictAwsKmsMasterKeyProvider(**kms_kwargs)

    def encrypt(self, data, *args, **kwargs):
        ciphertext, encryptor_header = self.client.encrypt(
            source=data,
            key_provider=self.master_key_provider)

        return ciphertext

    def decrypt(self, data, *args, **kwargs):
        plaintext, decrypted_header = self.client.decrypt(
            source=data,
            key_provider=self.master_key_provider)

        return plaintext.decode(encoding=self.encoding)
